*******************
Version 2 Interface
*******************

.. important::

   DataBroker release 1.0 includes support for old-style "v1" usage and
   new-style "v2" usage.  This section addresses databroker's new "v2" usage.
   It is still under development and subject to change in response to user
   feedback.

   For the stable usage "v1" usage, see :ref:`v1_index`. See
   :ref:`transition_plan` for more information.

.. toctree::
   :maxdepth: 1

   user/index
   administrator/index
   developer/index
